ColorPrimaries

Enum ColorPrimaries 

#[non_exhaustive]
pub enum ColorPrimaries { Bt709, Bt601, Bt2020, Unknown, }
Color primaries defining the color gamut (the range of colors that can be represented).

Different standards define different primary colors (red, green, blue points) which determine the overall range of colors that can be displayed.

Common Usage

  • BT.709: HD content, same as sRGB primaries
  • BT.601: SD content (NTSC or PAL)
  • BT.2020: Wide color gamut for UHD/HDR

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Bt709

ITU-R BT.709 primaries (same as sRGB, most common)



Bt601

ITU-R BT.601 primaries (SD video)



Bt2020

ITU-R BT.2020 primaries (wide color gamut for UHD/HDR)



Unknown

Color primaries are not specified or unknown

Implementations

Source

impl ColorPrimaries

pub const fn name(&self) -> &'static str

Returns the name of the color primaries as a human-readable string.

Examples
use ff_format::color::ColorPrimaries;

assert_eq!(ColorPrimaries::Bt709.name(), "bt709");
assert_eq!(ColorPrimaries::Bt2020.name(), "bt2020");
pub const fn is_wide_gamut(&self) -> bool

Returns true if this uses wide color gamut (BT.2020).

Examples
use ff_format::color::ColorPrimaries;

assert!(ColorPrimaries::Bt2020.is_wide_gamut());
assert!(!ColorPrimaries::Bt709.is_wide_gamut());
pub const fn is_unknown(&self) -> bool

Returns true if the color primaries are unknown.

Examples
use ff_format::color::ColorPrimaries;

assert!(ColorPrimaries::Unknown.is_unknown());
assert!(!ColorPrimaries::Bt709.is_unknown());